@@ -1,31 +1,7 @@
-"""\
-Copyright
-=========
-    - Copyright: 2011-2014 Ethan Furman
-    - Author: Ethan Furman
-    - Contact: ethan@stoneleaf.us
-    - Version: 0.80.00 as of 2014-10-30
+"""
+file path manipulation
 
-Redistribution and use in source and binary forms, with or without
-modification, are permitted provided that the following conditions are met:
-    - Redistributions of source code must retain the above copyright
-      notice, this list of conditions and the following disclaimer.
-    - Redistributions in binary form must reproduce the above copyright
-      notice, this list of conditions and the following disclaimer in the
-      documentation and/or other materials provided with the distribution.
-    - The name of the author may not be used to endorse or promote products
-      derived from this software without specific prior written permission.
-
-THIS SOFTWARE IS PROVIDED ''AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
-INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
-AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
-AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
-OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
-SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
-INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
-CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
-ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
-POSSIBILITY OF SUCH DAMAGE.
+Copyright: 2011-2015 Ethan Furman
 """
 
 from os import F_OK, R_OK, W_OK, X_OK
@@ -53,7 +29,7 @@ system_sep = _os.path.sep
 
 _is_win = _os.path.__name__ == 'ntpath'
 
-version = 0, 80, 2
+version = 0, 81, 5
 
 class Path(object):
     """\
@@ -207,7 +183,7 @@ class Path(object):
             for file in files:
                 Path(file).lchown(uid, gid)
 
-    if hasattr(_os, 'lexists'):
+    if hasattr(_os.path, 'lexists'):
 
         @staticmethod
         def lexists(name):
@@ -818,7 +794,7 @@ class Methods(object):
             for file in files:
                 _os.lchown(file, uid, gid)
 
-    if hasattr(_os, 'lexists'):
+    if hasattr(_os.path, 'lexists'):
 
         def lexists(self, file_name=None):
             if file_name is not None:
